@@ -75,7 +75,10 @@ def prepare_test(production_name, job_name, dependent_input=None):
     override_input, output_filetype = resolve_input_overrides(prod_data, job_name)
     if "job_name" in job_data["input"] and dependent_input is None:
         dependent_input = recursively_create_input(
-            production_name, job_data["input"]["job_name"], prod_data
+            production_name,
+            job_data["input"]["job_name"],
+            job_data["input"].get("filetype"),
+            prod_data,
         )
 
     # only create output directories if this is the job that's about to be run
@@ -103,8 +106,6 @@ def prepare_test(production_name, job_name, dependent_input=None):
 
     prodrun_config_path = out_dir / "prodConf_DaVinci_00012345_00006789_1.json"
 
-    if len(job_data["output"]) != 1:
-        raise NotImplementedError()
     prodrun_conf["output"]["types"] = job_data["output"]
 
     # force to use the file chosen by the user
@@ -190,6 +191,8 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id):
 
     # Download the job input
     input_paths = [x["path"] for x in job_info["test"]["input_files"]]
+    if not input_paths:
+        raise NotImplementedError("Failed to find any input files")
     if all("/" in x for x in input_paths):
         # It's an LFN so write the pool_xml_catalog.xml
         (out_dir / "pool_xml_catalog.xml").write_text(pool_xml_catalog(input_paths))
