@@ -155,16 +155,16 @@ def production_name_type(production_name):
     return production_name.strip("/")
 
 
-def recursively_create_input(production_name, job_name, prod_data):
+def recursively_create_input(production_name, job_name, filetype, prod_data):
     click.secho(
         f"Running {job_name} to provide the necessary input",
         fg="green",
     )
 
-    output_filetypes = prod_data[job_name]["output"]
-    if len(output_filetypes) != 1:
+    output_filetypes = [x.lower() for x in prod_data[job_name]["output"]]
+    if filetype.lower() not in output_filetypes:
         raise NotImplementedError(
-            "Testing jobs that take input from jobs with multiple outputs is not yet supported"
+            f"Looking for {filetype} but {job_name} only produces {output_filetypes}"
         )
 
     # Run the job the desired job depends on
@@ -178,7 +178,7 @@ def recursively_create_input(production_name, job_name, prod_data):
         # Set the dependent input to lower case to handle inconsistencies between
         # yaml definition and produced file
         dependent_input = (
-            output_dir + f"/00012345_00006789_1.{output_filetypes[0]}"
+            output_dir + f"/00012345_00006789_1.{filetype.lower()}"
         ).lower()
 
         # Set up a dictionary to map lower case output file names to their
